@@ -96,7 +96,11 @@ def test_gha_search_slow(test_db, test_gha_data):
     for d in all_data:
         version = d["details"]["max_affected_version_including"]
         if version and version != "*":
-            res = db.pkg_search(table, d["details"]["package"], version,)
+            res = db.pkg_search(
+                table,
+                d["details"]["package"],
+                version,
+            )
             assert len(res)
             assert res[0].to_dict()["package_issue"]
 
@@ -113,7 +117,12 @@ def test_gha_vendor_search(test_db, test_gha_data):
         vendor, _, _ = parse_cpe(d["details"]["cpe_uri"])
         version = d["details"]["max_affected_version_including"]
         if version and version != "*":
-            res = db.vendor_pkg_search(table, vendor, d["details"]["package"], version,)
+            res = db.vendor_pkg_search(
+                table,
+                vendor,
+                d["details"]["package"],
+                version,
+            )
             assert len(res)
             assert res[0].to_dict()["package_issue"]
 
