@@ -177,6 +177,22 @@ def test_version_build_compare():
     res = utils.version_compare("1.3.0", "1.2.0-beta", "1.3.2.0")
     assert res
 
+def test_version_build_diff_compare():
+    res = utils.version_compare("7.0.0", "*", "*", None, "2020-04-23t00-58-49z")
+    assert not res
+    res = utils.version_compare("7.0.0", "*", "*", None, "2018-05-16t23-35-33z")
+    assert not res
+    res = utils.version_compare("7.0.0", "2018-05-16t23-35-33z", "2020-04-23t00-58-49z")
+    assert not res
+    res = utils.version_compare("7.0.0", None, "2020-04-23t00-58-49z", "2020-04-23t00-58-49z", None)
+    assert not res
+    res = utils.version_compare("7.0.0", None, "2018-05-16t23-35-33z", "2018-05-16t23-35-33z", None)
+    assert not res
+    res = utils.version_compare("7.0.0", "*", None, "2020-04-23t00-58-49z", None)
+    assert not res
+    res = utils.version_compare("7.0.0", "*", None, "2018-05-16t23-35-33z", None)
+    assert not res
+
 
 def test_parse_uri():
     vendor, package, version = utils.parse_cpe(
