@@ -5,13 +5,39 @@ from datetime import datetime
 from enum import Enum
 
 # Known application package types
-KNOWN_PKG_TYPES = ["composer", "maven", "npm", "nuget", "pypi", "rubygems", "golang"]
+KNOWN_PKG_TYPES = [
+    "composer",
+    "maven",
+    "npm",
+    "nuget",
+    "pypi",
+    "rubygems",
+    "golang",
+    "crates",
+]
+
+# Maps variations of string to package types
+PKG_TYPES_MAP = {
+    "composer": ["php", "laravel", "wordpress", "joomla"],
+    "maven": ["jenkins", "java", "kotlin", "groovy"],
+    "npm": ["javascript", "node.js", "nodejs"],
+    "nuget": [".net_framework", "csharp", ".net_core"],
+    "pypi": ["python"],
+    "rubygems": ["ruby"],
+    "golang": ["go"],
+    "crates": ["rust"],
+}
 
 # CPE Regex
 CPE_REGEX = re.compile(
     "cpe:?:[^:]+:[^:]+:(?P<vendor>[^:]+):(?P<package>[^:]+):(?P<version>[^:]+)?"
 )
 
+# CPE Full Regex including unused parameters
+CPE_FULL_REGEX = re.compile(
+    "cpe:?:[^:]+:[^:]+:(?P<vendor>[^:]+):(?P<package>[^:]+):(?P<version>[^:]+):(?P<update>[^:]+):(?P<edition>[^:]+):(?P<lang>[^:]+):(?P<sw_edition>[^:]+):(?P<target_sw>[^:]+):(?P<target_hw>[^:]+):(?P<other>[^:]+)"
+)
+
 
 class VulnerabilitySource(metaclass=ABCMeta):
     @classmethod
@@ -191,15 +217,31 @@ class VulnerabilityDetail(object):
         if package_type in KNOWN_PKG_TYPES:
             return package_type
         parts = CPE_REGEX.match(cpe_uri)
+        # cpe:2.3:a:netaddr_project:netaddr:*:*:*:*:*:ruby:*:*
+        all_parts = CPE_FULL_REGEX.match(cpe_uri)
         if parts:
             type = parts.group("vendor")
             if type in KNOWN_PKG_TYPES:
                 return type
+            elif all_parts and (
+                (all_parts.group("target_sw") and all_parts.group("target_sw") != "*")
+                or (
+                    all_parts.group("sw_edition")
+                    and all_parts.group("sw_edition") != "*"
+                )
+            ):
+                for vk, vv in PKG_TYPES_MAP.items():
+                    target_sw = all_parts.group("target_sw")
+                    sw_edition = all_parts.group("sw_edition")
+                    if target_sw == vk or sw_edition == vk:
+                        return vk
+                    if target_sw in vv or sw_edition in vv:
+                        return vk
+                return type
             else:
                 # Unknown type. Just pass-through for now
                 return type
-        else:
-            return None
+        return None
 
     @staticmethod
     def from_dict(detail):
