@@ -57,6 +57,8 @@ def store(db, datas):
     :param datas: Data list to store
     :return: Stored packed documents
     """
+    if datas is None:
+        return None
     global index_data, vendor_index_data
     docs = storage.store(datas, db_file=db["db_file"], index_file=db["index_file"])
     # Re-read the index
