@@ -340,6 +340,14 @@ def version_compare(
         is_max_exclude = True
     if not min_version:
         min_version = "0"
+    # If compare_ver is semver compatible and min_version is * then max_version should be semver compatible
+    if (
+        compare_ver
+        and VersionInfo.isvalid(compare_ver)
+        and (not min_version or min_version == "*")
+        and not VersionInfo.isvalid(max_version)
+    ):
+        return False
     # Perform semver match once we have all the required versions
     if compare_ver and min_version and max_version:
         if semver_compatible(compare_ver, min_version, max_version):
